@@ -19,9 +19,9 @@
 
 __title__ = "eodag-cube"
 __description__ = "Data access for EODAG"
-__version__ = "0.2.0"
+__version__ = "0.3.0"
 __author__ = "CS GROUP - France (CSSI)"
-__author_email__ = "admin@geostorm.eu"
+__author_email__ = "eodag@csgroup.space"
 __url__ = "https://github.com/CS-SI/eodag-cube"
 __license__ = "Apache 2.0"
 __copyright__ = "Copyright 2021, CS GROUP - France, http://www.c-s.fr"
